@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::install;
+package Dist::Zilla::App::Command::install 6.007;
 # ABSTRACT: install your dist
-$Dist::Zilla::App::Command::install::VERSION = '6.005';
+
 use Dist::Zilla::App -command;
 
 #pod =head1 SYNOPSIS
@@ -70,7 +70,7 @@ Dist::Zilla::App::Command::install - install your dist
 
 =head1 VERSION
 
-version 6.005
+version 6.007
 
 =head1 SYNOPSIS
 
