@@ -1,8 +1,9 @@
-package Dist::Zilla::Plugin::MetaJSON;
+package Dist::Zilla::Plugin::MetaJSON 6.007;
 # ABSTRACT: produce a META.json
-$Dist::Zilla::Plugin::MetaJSON::VERSION = '6.005';
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
+use Moose::Util::TypeConstraints;
 
 use namespace::autoclean;
 
@@ -36,9 +37,15 @@ has filename => (
 #pod
 #pod =cut
 
+my $version_type = subtype(
+    as 'Num',
+    where { $_ >= 2 },
+    message { "MetaJSON version must be 2 or greater" },
+);
+
 has version => (
   is  => 'ro',
-  isa => 'Num',
+  isa => $version_type,
   default => '2',
 );
 
@@ -72,9 +79,10 @@ sub gather_files {
       my $converter = CPAN::Meta::Converter->new($distmeta);
       my $output    = $converter->convert(version => $self->version);
 
-      # note utf8 => 1 is *not* used - so unicode characters remain as-is in
-      # the resulting json string, and therefore an encoding must be used when
-      # the file is written to disk.
+      my $backend = JSON::MaybeXS::JSON();
+      $output->{x_serialization_backend} = sprintf '%s version %s',
+            $backend, $backend->VERSION;
+
       JSON::MaybeXS->new(canonical => 1, pretty => 1, ascii => 1)->encode($output)
       . "\n";
     },
@@ -114,7 +122,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 6.005
+version 6.007
 
 =head1 DESCRIPTION
 
