@@ -1,6 +1,6 @@
-package Dist::Zilla::Plugin::TemplateModule;
+package Dist::Zilla::Plugin::TemplateModule 6.007;
 # ABSTRACT: a simple module-from-template plugin
-$Dist::Zilla::Plugin::TemplateModule::VERSION = '6.005';
+
 use Moose;
 with qw(Dist::Zilla::Role::ModuleMaker Dist::Zilla::Role::TextTemplate);
 
@@ -107,7 +107,7 @@ Dist::Zilla::Plugin::TemplateModule - a simple module-from-template plugin
 
 =head1 VERSION
 
-version 6.005
+version 6.007
 
 =head1 DESCRIPTION
 
