@@ -1,6 +1,6 @@
-package Dist::Zilla::PluginBundle::Basic;
+package Dist::Zilla::PluginBundle::Basic 6.007;
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
-$Dist::Zilla::PluginBundle::Basic::VERSION = '6.005';
+
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -78,7 +78,7 @@ Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPA
 
 =head1 VERSION
 
-version 6.005
+version 6.007
 
 =head1 DESCRIPTION
 
