@@ -1,6 +1,6 @@
-package Dist::Zilla::Role::PrereqSource;
+package Dist::Zilla::Role::PrereqSource 6.007;
 # ABSTRACT: something that registers prerequisites
-$Dist::Zilla::Role::PrereqSource::VERSION = '6.005';
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
@@ -29,7 +29,7 @@ Dist::Zilla::Role::PrereqSource - something that registers prerequisites
 
 =head1 VERSION
 
-version 6.005
+version 6.007
 
 =head1 DESCRIPTION
 
